@@ -1,6 +1,8 @@
 package pkg
 
 import (
+	"fmt"
+	"strings"
 	"testing"
 
 	"github.com/scylladb/go-set"
@@ -8,6 +10,7 @@ import (
 	"github.com/stretchr/testify/assert"
 
 	"github.com/anchore/syft/syft/artifact"
+	"github.com/anchore/syft/syft/cpe"
 	"github.com/anchore/syft/syft/file"
 	syftFile "github.com/anchore/syft/syft/file"
 	syftPkg "github.com/anchore/syft/syft/pkg"
@@ -258,7 +261,7 @@ func TestNew(t *testing.T) {
 			},
 		},
 		{
-			name: "golang-bin-metadata",
+			name: "golang-metadata",
 			syftPkg: syftPkg.Package{
 				MetadataType: syftPkg.GolangBinMetadataType,
 				Metadata: syftPkg.GolangBinMetadata{
@@ -275,6 +278,18 @@ func TestNew(t *testing.T) {
 				MainModule:        "myMainModule",
 			},
 		},
+		{
+			name: "golang-mod-metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.GolangModMetadataType,
+				Metadata: syftPkg.GolangModMetadata{
+					H1Digest: "h1:as234NweNNTNWEtt13nwNENTt",
+				},
+			},
+			metadata: GolangModMetadata{
+				H1Digest: "h1:as234NweNNTNWEtt13nwNENTt",
+			},
+		},
 		{
 			name: "php-composer-metadata",
 			syftPkg: syftPkg.Package{
@@ -361,6 +376,48 @@ func TestNew(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "rebar-metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.RebarLockMetadataType,
+				Metadata: syftPkg.RebarLockMetadata{
+					Name:    "rebar",
+					Version: "v0.1.1",
+				},
+			},
+		},
+		{
+			name: "npm-package-lock-metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.NpmPackageLockJSONMetadataType,
+				Metadata: syftPkg.NpmPackageLockJSONMetadata{
+					Resolved:  "resolved",
+					Integrity: "sha1:ab7d8979989b7a98d97",
+				},
+			},
+		},
+		{
+			name: "mix-lock-metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.MixLockMetadataType,
+				Metadata: syftPkg.MixLockMetadata{
+					Name:    "mix-lock",
+					Version: "v0.1.2",
+				},
+			},
+		},
+		{
+			name: "pipfile-lock-metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.PythonPipfileLockMetadataType,
+				Metadata: syftPkg.PythonPipfileLockMetadata{
+					Hashes: []string{
+						"sha1:ab8v88a8b88d8d8c88b8s765s47",
+					},
+					Index: "1",
+				},
+			},
+		},
 		{
 			name: "binary-metadata",
 			syftPkg: syftPkg.Package{
@@ -426,7 +483,7 @@ func TestFromCatalog_GeneratesCPEs(t *testing.T) {
 	catalog.Add(syftPkg.Package{
 		Name:    "first",
 		Version: "1",
-		CPEs: []syftPkg.CPE{
+		CPEs: []cpe.CPE{
 			{},
 		},
 	})
@@ -495,28 +552,41 @@ func Test_RemoveBinaryPackagesByOverlap(t *testing.T) {
 		expectedPackages []string
 	}{
 		{
-			name:             "includes all packages without overlap",
-			sbom:             catalogWithBinaryOverlaps([]string{"go"}, []string{}),
-			expectedPackages: []string{"go"},
+			name: "includes all packages without overlap",
+			sbom: catalogWithOverlaps(
+				[]string{":go@1.18", "apk:node@19.2-r1", "binary:python@3.9"},
+				[]string{}),
+			expectedPackages: []string{":go@1.18", "apk:node@19.2-r1", "binary:python@3.9"},
 		},
 		{
-			name:             "excludes single package by overlap",
-			sbom:             catalogWithBinaryOverlaps([]string{"go", "node"}, []string{"node"}),
-			expectedPackages: []string{"go"},
+			name: "excludes single package by overlap",
+			sbom: catalogWithOverlaps(
+				[]string{"apk:go@1.18", "apk:node@19.2-r1", "binary:node@19.2"},
+				[]string{"apk:node@19.2-r1 -> binary:node@19.2"}),
+			expectedPackages: []string{"apk:go@1.18", "apk:node@19.2-r1"},
 		},
 		{
-			name:             "excludes multiple package by overlap",
-			sbom:             catalogWithBinaryOverlaps([]string{"go", "node", "python", "george"}, []string{"node", "george"}),
-			expectedPackages: []string{"go", "python"},
+			name: "excludes multiple package by overlap",
+			sbom: catalogWithOverlaps(
+				[]string{"apk:go@1.18", "apk:node@19.2-r1", "binary:node@19.2", "apk:python@3.9-r9", ":python@3.9"},
+				[]string{"apk:node@19.2-r1 -> binary:node@19.2", "apk:python@3.9-r9 -> :python@3.9"}),
+			expectedPackages: []string{"apk:go@1.18", "apk:node@19.2-r1", "apk:python@3.9-r9"},
+		},
+		{
+			name: "does not exclude with different types",
+			sbom: catalogWithOverlaps(
+				[]string{"rpm:node@19.2-r1", "apk:node@19.2"},
+				[]string{"rpm:node@19.2-r1 -> apk:node@19.2"}),
+			expectedPackages: []string{"apk:node@19.2", "rpm:node@19.2-r1"},
 		},
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			catalog := RemoveBinaryPackagesByOverlap(test.sbom.catalog, test.sbom.relationships)
+			catalog := removePackagesByOverlap(test.sbom.catalog, test.sbom.relationships)
 			pkgs := FromCatalog(catalog, SynthesisConfig{})
 			var pkgNames []string
 			for _, p := range pkgs {
-				pkgNames = append(pkgNames, p.Name)
+				pkgNames = append(pkgNames, fmt.Sprintf("%s:%s@%s", p.Type, p.Name, p.Version))
 			}
 			assert.EqualValues(t, test.expectedPackages, pkgNames)
 		})
@@ -528,29 +598,53 @@ type catalogRelationships struct {
 	relationships []artifact.Relationship
 }
 
-func catalogWithBinaryOverlaps(packages []string, overlaps []string) catalogRelationships {
+func catalogWithOverlaps(packages []string, overlaps []string) catalogRelationships {
 	var pkgs []syftPkg.Package
 	var relationships []artifact.Relationship
 
-	for _, name := range packages {
+	toPkg := func(str string) syftPkg.Package {
+		var typ, name, version string
+		s := strings.Split(strings.TrimSpace(str), ":")
+		if len(s) > 1 {
+			typ = s[0]
+			str = s[1]
+		}
+		s = strings.Split(str, "@")
+		name = s[0]
+		if len(s) > 1 {
+			version = s[1]
+		}
+
 		p := syftPkg.Package{
-			Name: name,
-			Type: syftPkg.BinaryPkg,
+			Type:    syftPkg.Type(typ),
+			Name:    name,
+			Version: version,
 		}
 		p.SetID()
 
-		for _, overlap := range overlaps {
-			if overlap == name {
-				relationships = append(relationships, artifact.Relationship{
-					From: p,
-					To:   p,
-					Type: artifact.OwnershipByFileOverlapRelationship,
-				})
-			}
-		}
+		return p
+	}
 
+	for _, pkg := range packages {
+		p := toPkg(pkg)
 		pkgs = append(pkgs, p)
 	}
+
+	for _, overlap := range overlaps {
+		parts := strings.Split(overlap, "->")
+		if len(parts) < 2 {
+			panic("invalid overlap, use -> to specify, e.g.: pkg1->pkg2")
+		}
+		from := toPkg(parts[0])
+		to := toPkg(parts[1])
+
+		relationships = append(relationships, artifact.Relationship{
+			From: from,
+			To:   to,
+			Type: artifact.OwnershipByFileOverlapRelationship,
+		})
+	}
+
 	catalog := syftPkg.NewCatalog(pkgs...)
 
 	return catalogRelationships{
