@@ -11,18 +11,11 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/syft/syft"
+	"github.com/anchore/syft/syft/cpe"
 	"github.com/anchore/syft/syft/linux"
-	"github.com/anchore/syft/syft/pkg"
 	"github.com/anchore/syft/syft/source"
 )
 
-func must(c pkg.CPE, e error) pkg.CPE {
-	if e != nil {
-		panic(e)
-	}
-	return c
-}
-
 func assertAs(expected string) assert.ErrorAssertionFunc {
 	return func(t assert.TestingT, err error, i ...interface{}) bool {
 		return assert.ErrorContains(t, errors.New(expected), err.Error())
@@ -193,7 +186,7 @@ func TestParseAttestation(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.Name, func(t *testing.T) {
-			pkgs, _, err := syftSBOMProvider(tt.Input, ProviderConfig{
+			pkgs, _, _, err := syftSBOMProvider(tt.Input, ProviderConfig{
 				SyftProviderConfig: SyftProviderConfig{
 					AttestationPublicKey: tt.Key,
 				},
@@ -228,8 +221,8 @@ func TestParseSyftJSON(t *testing.T) {
 						"GPL-2.0-only",
 					},
 					Type: "apk",
-					CPEs: []pkg.CPE{
-						must(pkg.NewCPE("cpe:2.3:a:alpine:alpine_baselayout:3.2.0-r6:*:*:*:*:*:*:*")),
+					CPEs: []cpe.CPE{
+						cpe.Must("cpe:2.3:a:alpine:alpine_baselayout:3.2.0-r6:*:*:*:*:*:*:*"),
 					},
 					PURL: "pkg:alpine/alpine-baselayout@3.2.0-r6?arch=x86_64",
 					Upstreams: []UpstreamPackage{
@@ -252,9 +245,9 @@ func TestParseSyftJSON(t *testing.T) {
 						"LGPL-3.0-or-later",
 					},
 					Type: "dpkg",
-					CPEs: []pkg.CPE{
-						must(pkg.NewCPE("cpe:2.3:a:*:fake:1.2.0:*:*:*:*:*:*:*")),
-						must(pkg.NewCPE("cpe:2.3:a:fake:fake:1.2.0:*:*:*:*:*:*:*")),
+					CPEs: []cpe.CPE{
+						cpe.Must("cpe:2.3:a:*:fake:1.2.0:*:*:*:*:*:*:*"),
+						cpe.Must("cpe:2.3:a:fake:fake:1.2.0:*:*:*:*:*:*:*"),
 					},
 					PURL: "pkg:deb/debian/fake@1.2.0?arch=x86_64",
 					Upstreams: []UpstreamPackage{
@@ -278,9 +271,9 @@ func TestParseSyftJSON(t *testing.T) {
 						"LGPL-3.0-or-later",
 					},
 					Type: "java-archive",
-					CPEs: []pkg.CPE{
-						must(pkg.NewCPE("cpe:2.3:a:*:gmp:6.2.0-r0:*:*:*:*:*:*:*")),
-						must(pkg.NewCPE("cpe:2.3:a:gmp:gmp:6.2.0-r0:*:*:*:*:*:*:*")),
+					CPEs: []cpe.CPE{
+						cpe.Must("cpe:2.3:a:*:gmp:6.2.0-r0:*:*:*:*:*:*:*"),
+						cpe.Must("cpe:2.3:a:gmp:gmp:6.2.0-r0:*:*:*:*:*:*:*"),
 					},
 					PURL:         "pkg:alpine/gmp@6.2.0-r0?arch=x86_64",
 					MetadataType: JavaMetadataType,
@@ -324,7 +317,7 @@ func TestParseSyftJSON(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.Fixture, func(t *testing.T) {
-			pkgs, context, err := syftSBOMProvider(test.Fixture, ProviderConfig{})
+			pkgs, context, _, err := syftSBOMProvider(test.Fixture, ProviderConfig{})
 			if err != nil {
 				t.Fatalf("unable to parse: %+v", err)
 			}
@@ -353,7 +346,7 @@ func TestParseSyftJSON(t *testing.T) {
 }
 
 func TestParseSyftJSON_BadCPEs(t *testing.T) {
-	pkgs, _, err := syftSBOMProvider("test-fixtures/syft-java-bad-cpes.json", ProviderConfig{})
+	pkgs, _, _, err := syftSBOMProvider("test-fixtures/syft-java-bad-cpes.json", ProviderConfig{})
 	assert.NoError(t, err)
 	assert.Len(t, pkgs, 1)
 }
@@ -379,9 +372,9 @@ var springImageTestCase = struct {
 			Language: "java",
 			Licenses: []string{},
 			Type:     "java-archive",
-			CPEs: []pkg.CPE{
-				must(pkg.NewCPE("cpe:2.3:a:charsets:charsets:*:*:*:*:*:java:*:*")),
-				must(pkg.NewCPE("cpe:2.3:a:charsets:charsets:*:*:*:*:*:maven:*:*")),
+			CPEs: []cpe.CPE{
+				cpe.Must("cpe:2.3:a:charsets:charsets:*:*:*:*:*:java:*:*"),
+				cpe.Must("cpe:2.3:a:charsets:charsets:*:*:*:*:*:maven:*:*"),
 			},
 			PURL:         "",
 			MetadataType: JavaMetadataType,
@@ -399,9 +392,9 @@ var springImageTestCase = struct {
 			Language: "java",
 			Licenses: []string{},
 			Type:     "java-archive",
-			CPEs: []pkg.CPE{
-				must(pkg.NewCPE("cpe:2.3:a:tomcat_embed_el:tomcat-embed-el:9.0.27:*:*:*:*:java:*:*")),
-				must(pkg.NewCPE("cpe:2.3:a:tomcat-embed-el:tomcat_embed_el:9.0.27:*:*:*:*:maven:*:*")),
+			CPEs: []cpe.CPE{
+				cpe.Must("cpe:2.3:a:tomcat_embed_el:tomcat-embed-el:9.0.27:*:*:*:*:java:*:*"),
+				cpe.Must("cpe:2.3:a:tomcat-embed-el:tomcat_embed_el:9.0.27:*:*:*:*:maven:*:*"),
 			},
 			PURL:         "",
 			MetadataType: JavaMetadataType,
